@@ -1,13 +1,10 @@
 /******************************************************************************
 *   KBlocks, a falling blocks game by KDE                                     *
-*   Copyright (C) 2010-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
+*   SPDX-FileCopyrightText: 2010-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
 *                           Zhongjie Cai <squall.leonhart.cai@gmail.com>      *
 *                           Julian Helfferich <julian.helfferich@mailbox.org> *
 *                                                                             *
-*   This program is free software; you can redistribute it and/or modify      *
-*   it under the terms of the GNU General Public License as published by      *
-*   the Free Software Foundation; either version 2 of the License, or         *
-*   (at your option) any later version.                                       *
+*   SPDX-License-Identifier: GPL-2.0-or-later
 ******************************************************************************/
 #include "KBlocksScene.h"
 
@@ -165,15 +162,17 @@ void KBlocksScene::setSoundsEnabled(bool enabled)
     mpSnd->setSoundsEnabled(enabled);
 }
 
-void KBlocksScene::readSettings(const QSize &viewSize)
+void KBlocksScene::loadTheme(const KgTheme *theme)
 {
-    if (mpGrafx->theme()->fileName() != Settings::theme()) {
-        mpGrafx->loadTheme(Settings::theme());
-        mpGrafx->adjustForSize(viewSize);
-        updateDimensions();
-        // also update sounds fo rthe theme
-        mpSnd->loadTheme(Settings::theme());
-    }
+    mpGrafx->loadTheme(theme);
+    mpSnd->loadTheme(theme);
+    // update layout to new theme data
+    updateDimensions();
+}
+
+void KBlocksScene::readSettings()
+{
+    // nothing to do currently, no other settings beside the theme, which is handled separately
 }
 
 void KBlocksScene::startGame()
